@@ -36,6 +36,7 @@ from operator import itemgetter as ItemAt
 from typing import Any, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from babelplot.brick.enum import EnumMembers, EnumValues
+from babelplot.brick.log import LOGGER
 
 
 UNAVAILABLE_for_this_DIM = None
@@ -62,6 +63,7 @@ class plot_e(enum_t):
     POLYLINES = "polylines"
     POLYGON = "polygon"
     POLYGONS = "polygons"
+    ARROWS = "arrows"
     ELEVATION = "elevation"
     ISOSET = "isoset"
     MESH = "mesh"
@@ -127,15 +129,14 @@ class plot_e(enum_t):
         if with_descriptions:
             descriptions = []
             for member in members:
-                description = PLOT_DESCRIPTION[eval(member)]
-                arguments = "\n".join(
-                    f"    Dim.{_dim}: " + ", ".join(_arg)
-                    for _dim, _arg in zip(description[2], description[3])
-                )
+                description = PLOT_DESCRIPTION[
+                    cls[member[(cls.__name__.__len__() + 1) :]]
+                ]
+                dimensions = ", ".join(str(_dim) for _dim in description[2])
                 descriptions.append(
-                    f"{member}: {description[0]}\n{description[1]}\n{arguments}"
+                    f"{member}: {description[0]}\n{description[1]}\nDim(s): {dimensions}"
                 )
-            descriptions = "\n\nDescriptions:\n" + "\n".join(descriptions)
+            descriptions = "\n\n--- Descriptions:\n" + "\n\n".join(descriptions)
         else:
             descriptions = ""
 
@@ -157,7 +158,7 @@ class plot_e(enum_t):
         if name in KNOWN_PLOT_TYPES:
             return cls(name)
 
-        raise ValueError(f"{name}: Invalid plot type. Expected={KNOWN_PLOT_TYPES}.")
+        LOGGER.error(f"{name}: Invalid plot type. Expected={KNOWN_PLOT_TYPES}.")
 
 
 KNOWN_PLOT_TYPES = EnumValues(plot_e)
@@ -167,90 +168,135 @@ backend_plots_per_type_h = Tuple[Union[type(UNAVAILABLE_for_this_DIM), Callable]
 backend_plots_h = Dict[plot_e, backend_plots_per_type_h]
 
 
+_NUMPY_ARRAY_PAGE = (
+    "https://numpy.org/doc/stable/reference/generated/numpy.ndarray.html"
+)
+
+
 # The second element of the description is a tuple of the dimensions the plot type is available in
 PLOT_DESCRIPTION = {
     # Brief description
     # Description
     # Valid frame dimension(s)
-    # For each dimension, brief description of the positional-only arguments
     plot_e.SCATTER: (
         "Set of Points",
-        "Each point of a scatter plot is plotted using a so-called marker.",
+        "A set of points X, (X, Y), or (X, Y, Z) depending on the dimension. They are plotted using a so-called "
+        "marker.\n"
+        "Required arguments: X coordinates, Y coordinates, Z coordinates (depending on the dimension).",
         (1, 2, 3),
-        (("Xs",), ("Xs", "Ys"), ("Xs", "Ys", "Zs")),
     ),
     plot_e.POLYLINE: (
         "Polygonal Chain",
         "A polygonal chain is a connected series of line segments specified by a sequence of points enumerated "
-        "consecutively called vertices. "
+        "consecutively called vertices [https://en.wikipedia.org/wiki/Polygonal_chain]. "
         "It typically describes an open path. It can have markers like a scatter plot.\n"
         "A polygonal chain may also be called a polygonal curve, polygonal path, polyline, piecewise linear curve, "
         "or broken line.\n"
-        "-- Description adapted from Wikipedia, The Free Encyclopedia [https://en.wikipedia.org/wiki/Polygonal_chain].",
+        "Required arguments: X coordinates, Y coordinates, Z coordinates (depending on the dimension).",
         (2, 3),
-        (("Xs", "Ys"), ("Xs", "Ys", "Zs")),
     ),
     plot_e.POLYLINES: (
         "Set of Polygonal Chains",
-        'See "Polygonal Chain". '
-        "Use case: some plotting libraries may deal with sets more efficiently than looping over the chains in Python.",
+        'See "Polygonal Chain". Use case: some plotting libraries may deal with sets more efficiently than looping '
+        "over the chains in Python.\n"
+        "Required arguments: List of X coordinates, list of Y coordinates, list of Z coordinates (depending on the "
+        "dimension).",
         (2, 3),
-        (("(Xs, ...)", "(Ys, ...)"), ("(Xs, ...)", "(Ys, ...)", "(Zs, ...)")),
     ),
     plot_e.POLYGON: (
         "Polygon",
-        "A polygon is a closed polygonal chain represented as a sequence of vertices "
-        "without repetition of the first one at the end of the sequence.",
+        "A polygon is a closed polygonal chain represented as a sequence of vertices without repetition of the first "
+        'one at the end of the sequence. See "Polygonal Chain".\n'
+        "Required arguments: X coordinates and Y coordinates.",
         (2,),
-        (("Xs", "Ys"),),
     ),
     plot_e.POLYGONS: (
         "Set of Polygons",
-        'See "Polygon". '
-        "Use case: some plotting libraries may deal with sets more efficiently "
-        "than looping over the polygons in Python.",
+        'See "Polygon". Use case: some plotting libraries may deal with sets more efficiently than looping over the '
+        "polygons in Python.\n"
+        "Required arguments: List of X coordinates and list of Y coordinates.",
         (2,),
-        (("(Xs, ...)", "(Ys, ...)"),),
+    ),
+    plot_e.ARROWS: (
+        "Set of Arrows",
+        "A set, or field, of arrows.\n"
+        "Required arguments: U arrow components, V arrow components, W arrow components (depending on the dimension).\n"
+        "Optional arguments: X coordinates, Y coordinates, Z coordinates passed as first, second and third positional "
+        "arguments (depending on the dimension).",
+        (2, 3),
     ),
     plot_e.ELEVATION: (
         "Elevation Surface",
-        "An elevation surface is defined as the set of points (X,Y,Z) where Z is the (unique) \"elevation\" computed "
-        "by a function f for each planar coordinates (X,Y): Z = f(X,Y). Z must be passed as a positional argument. "
-        "X and Y can be passed as keyword arguments \"x\" and \"y\" to specify a non-regular grid.",
+        'An elevation surface is defined as the set of points (X,Y,Z) where Z is the (unique) "elevation" computed by '
+        "a function f for each planar coordinates (X,Y): Z = f(X,Y).\n"
+        "Required argument: An elevation map Z.\n"
+        'Optional arguments: X and Y passed as keyword arguments "x" and "y" to specify a non-regular grid.',
         (3,),
-        (("Zs",),),
     ),
     plot_e.ISOSET: (
         "Isoset",
-        "An isoset, or level set, is the set of points at which a function f takes a given value (or level) V: "
-        "{point | f(point)=V} where point=X,Y in 2 dimensions or X,Y,Z in 3 dimensions. "
-        "In 2 dimensions, an isoset is also called an isocontour. In 3 dimensions, it is also called an isosurface. "
-        "The set {point | f(point)} and V must be passed as positional arguments. X, Y, and Z can be passed as keyword "
-        "arguments \"x\", \"y\", and \"z\" to specify a non-regular grid.",
+        f"An isoset, or level set, is the set of points at which a function f takes a given value (or level) V: "
+        f"{{point | f(point)=V}} where point=X,Y in 2 dimensions or X,Y,Z in 3 dimensions. In 2 dimensions, an isoset "
+        f"is also called an isocontour. In 3 dimensions, it is also called an isosurface.\n"
+        f"Required arguments: A 2- or 3-dimensional Numpy array [{_NUMPY_ARRAY_PAGE}] with the values f(point) for "
+        f"each point in a domain, and V.\n"
+        f'Optional arguments: X, Y, and Z (depending on the dimension) passed as keyword arguments "x", "y", and '
+        f'"z" to specify a non-regular grid.',
         (2, 3),
-        (("Fs", "V"), ("Fs", "V")),
     ),
-    plot_e.MESH: ("Triangular Mesh", "", (3,), ((),)),
-    plot_e.PMESH: ("Polygonal Mesh", "Use case: probably rare.", (3,), ((),)),
-    plot_e.BARH: ("Horizontal Bar Plot", "", (2,), ((),)),
+    plot_e.MESH: (
+        "Triangular Mesh",
+        f"A triangular mesh is a 2-dimensional surface in the 3-dimensional space. It is composed of triangles T "
+        f"defined by vertices V.\n"
+        f"Required arguments: Some triangles as an Nx3-Numpy array [{_NUMPY_ARRAY_PAGE}] of vertex indices (between "
+        f"zero and M-1), and the vertices coordinates as an Mx3-Numpy array.",
+        (3,),
+    ),
+    plot_e.PMESH: (
+        "Polygonal Mesh",
+        'A mesh with polygonal faces instead of triangular ones. See "Triangular Mesh". Use case: probably rare.',
+        (3,),
+    ),
+    plot_e.BARH: (
+        "Horizontal Bar Plot",
+        'See "Vertical Bar Plot".\n'
+        "Required argument: bar widths W\n"
+        "Optional arguments: Y coordinates of the bars passed as first positional argument and width offsets passed as "
+        '"offset".',
+        (2,),
+    ),
     plot_e.BARV: (
         "Vertical Bar Plot",
-        "A vertical bar plot is equivalent to a 2-dimensional histogram.",
+        "A vertical bar plot is equivalent to a 2-dimensional histogram.\n"
+        "Required argument: bar heights H\n"
+        "Optional arguments: X coordinates of the bars passed as first positional argument and height offsets passed "
+        'as "offset".',
         (2,),
-        ((),),
     ),
     plot_e.BAR3: (
         "Three-dimensional Bar Plot",
-        "A three-dimensional bar plot is equivalent to a 3-dimensional histogram.",
+        "A three-dimensional bar plot is equivalent to a 3-dimensional histogram.\n"
+        "Required argument: bar heights H.\n"
+        "Optional arguments: X coordinates and Y coordinates of the bars passed as first and second positional "
+        'arguments, width(s) and depth(s) of bars passed as "width" and "depth", and height offsets passed as '
+        '"offset".',
         (3,),
-        ((),),
     ),
-    plot_e.PIE: ("Pie Plot", "", (2,), ((),)),
+    plot_e.PIE: (
+        "Pie Plot",
+        "A pie plot, or pie chart or circle chart, is a circular statistical graphic which is divided into slices to "
+        "illustrate proportions. The angle of each slice is proportional to the quantity it represents "
+        "[https://en.wikipedia.org/wiki/Pie_chart].\n"
+        "Required argument: Proportions or quantities.",
+        (2,),
+    ),
     plot_e.IMAGE: (
         "Two-dimensional Image",
-        "When plotting a 2-dimensional image in a 3-dimensional frame, a plotting plane specification is required.",
+        "A grayscale or color two-dimensional image, with or without alpha channel. When plotting a 2-dimensional "
+        "image in a 3-dimensional frame, a plotting plane specification is required.\n"
+        "Required argument: An image.\n"
+        'Optional argument: An axis-aligned plane position passed as a keyword argument "x", "y", or "z".',
         (2, 3),
-        ((),),
     ),
 }
 
@@ -283,10 +329,12 @@ def TranslatedArguments(
     from_kwargs_to_args = []
     for key, value in kwargs.items():
         # It is important to search for specific translation first (i.e. (plot_function, key), as opposed to key alone)
-        if (idx := translations.get((plot_function, key))) is None:
+        if (translation := translations.get((plot_function, key))) is None:
             output_2[translations.get(key, key)] = value
+        elif isinstance(translation, int):
+            from_kwargs_to_args.append((value, translation))
         else:
-            from_kwargs_to_args.append((value, idx))
+            output_2[translation] = value
     for value, idx in sorted(from_kwargs_to_args, key=ItemAt(1)):
         output_1.insert(idx, value)
 
