@@ -35,6 +35,7 @@ from typing import Any, TypeVar, Union
 
 from babelplot.backend.runtime import BackendTranslations
 from babelplot.backend.specification.plot import TranslatedArguments
+from babelplot.brick.log import LOGGER
 
 
 backend_figure_h = TypeVar("backend_figure_h")
@@ -45,7 +46,7 @@ backend_element_h = Union[backend_figure_h, backend_frame_h, backend_plot_h]
 
 @dtcl.dataclass(repr=False, eq=False)
 class babelplot_element_t:
-    pbe: str = None
+    pbe: str = None  # Cannot be backend_e since external backends would not be accounted for then
     # In case the backend does not make it easy to retrieve some properties, they are stored here. E.g., how to retrieve
     # the marker of a scatter plot in Matplotlib?
     # /!\ Do not forget to initialize it with kwargs during element instanciation.
@@ -76,7 +77,7 @@ class babelplot_element_t:
 
         if (n_individials := args.__len__()) > 0:
             if (n_individials % 2) > 0:
-                raise ValueError(
+                LOGGER.error(
                     f"N. argument(s)={n_individials}: Properties are not passed in matching key-value pairs. "
                     f"Expected=Even number."
                 )
