@@ -36,7 +36,9 @@ from multiprocessing import Process as process_t
 from typing import List, Optional, Sequence, Tuple, Union
 
 from babelplot.backend.runtime import BackendTranslations
+from babelplot.backend.specification.implemented import backend_e
 from babelplot.backend.specification.plot import TranslatedArguments
+from babelplot.brick.log import LOGGER
 from babelplot.type.base import babelplot_element_t as base_figure_t
 from babelplot.type.base import backend_figure_h, backend_frame_h
 from babelplot.type.dimension import dim_e
@@ -83,9 +85,9 @@ class figure_t(base_figure_t):
             dim = dim_e.NewFromName(dim)
 
         if (where := (row, col)) in self.locations:
-            raise ValueError(f"{where}: Frame grid cell already filled")
+            LOGGER.error(f"{where}: Frame grid cell already filled")
         if (row < 0) and (col < 0):
-            raise ValueError(f"{where}: Grid coordinates cannot be both negative")
+            LOGGER.error(f"{where}: Grid coordinates cannot be both negative")
         if row < 0:
             row = self.shape[0]
         elif col < 0:
@@ -113,7 +115,7 @@ class figure_t(base_figure_t):
     def LocationOfFrame(self, frame: frame_t, /) -> Tuple[int, int]:
         """"""
         if frame not in self.frames:
-            raise ValueError(f"{frame}: Not a frame of the figure.")
+            LOGGER.error(f"{frame}: Not a frame of the figure.")
 
         where = self.frames.index(frame)
 
@@ -129,10 +131,10 @@ class figure_t(base_figure_t):
     ) -> Optional[frame_t]:
         """"""
         if (row < 0) or (col < 0):
-            raise ValueError(f"({row},{col}): Row or col cannot be negative.")
+            LOGGER.error(f"({row},{col}): Row or col cannot be negative.")
         if (row >= self.shape[0]) or (col >= self.shape[1]):
             if strict_mode:
-                raise ValueError(
+                LOGGER.error(
                     f"({row},{col}): Out-of-bound cell coordinates. "
                     f"Expected: row<{self.shape[0]} and col<{self.shape[1]}."
                 )
@@ -242,7 +244,22 @@ def ShowAllFigures(
     modal: bool = True,
 ) -> None:
     """"""
-    while _unshown_figures.__len__() > 1:
-        _unshown_figures[0].Show(modal=False)
-    if _unshown_figures.__len__() > 0:
-        _unshown_figures[0].Show(modal=modal)
+    if all(_fgr.pbe == backend_e.MATPLOTLIB.value for _fgr in _unshown_figures):
+        for figure in _unshown_figures:
+            if hasattr(figure, "BackendShowPreparation"):
+                figure.BackendShowPreparation(
+                    figure.backend, figure.shape, figure.frames, figure.locations
+                )
+
+        # /!\ Must be removed when closed
+        _shown_figures.extend(_unshown_figures)
+        _unshown_figures.clear()
+
+        import matplotlib.pyplot as pypl  # noqa
+
+        pypl.show()
+    else:
+        while _unshown_figures.__len__() > 1:
+            _unshown_figures[0].Show(modal=False)
+        if _unshown_figures.__len__() > 0:
+            _unshown_figures[0].Show(modal=modal)
