@@ -37,6 +37,7 @@ from babelplot.backend.specification.plot import (
     backend_plots_h,
     plot_e,
 )
+from babelplot.brick.log import LOGGER
 from babelplot.type.base import babelplot_element_t as base_plot_t
 from babelplot.type.base import backend_plot_h
 
@@ -59,19 +60,19 @@ def BackendPlotFromPlotE(
     if plot in backend_plots:
         description = backend_plots[plot]
         if description.__len__() <= frame_dim - 1:
-            raise TypeError(
+            LOGGER.error(
                 f"{plot.value}: Invalid {backend} plotting object for a {frame_dim}-dimensional frame."
             )
 
         description = description[frame_dim - 1]
         if description is UNAVAILABLE_for_this_DIM:
-            raise TypeError(
+            LOGGER.error(
                 f"{plot.value}: Unavailable {backend} plotting object for a {frame_dim}-dimensional frame."
             )
 
         return description
 
-    raise TypeError(f"{plot.value}: Unknown {backend} plotting object.")
+    LOGGER.error(f"{plot.value}: Unknown {backend} plotting object.")
 
 
 def BackendPlotFromAny(
