@@ -29,9 +29,11 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 
+import numpy as nmpy
 import plotly.graph_objects as plot  # noqa
 
 from babelplot import NewBabelPlotFigure, ShowAllFigures, plot_e
+from babelplot.type.dimension import dim_e
 
 
 figure_1 = NewBabelPlotFigure(pbe="bokeh")
@@ -72,4 +74,12 @@ frame = figure_3.AddFrame(plot_width=400, plot_height=200)
 frame.AddPlot(plot_e.SCATTER, [1, 2, 3], [2, 4, 6])
 
 
+# x, y, z = nmpy.ogrid[-10:10:20j, -10:10:20j, -10:10:20j]
+# s = nmpy.sin(x * y * z) / (x * y * z)
+#
+# figure_4 = NewBabelPlotFigure(pbe="vedo")
+# frame = figure_4.AddFrame(dim=dim_e.XYZ)
+# frame.AddPlot(plot_e.ISOSET, s, s.min() + 0.1 * s.ptp())
+
+
 ShowAllFigures()
